@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KIMAP_LOGOUTJOB_H
-#define KIMAP_LOGOUTJOB_H
+#pragma once
 
 #include "kimap_export.h"
 
@@ -13,7 +12,6 @@
 
 namespace KIMAP
 {
-
 class Session;
 class LogoutJobPrivate;
 
@@ -35,4 +33,3 @@ protected:
 
 }
 
-#endif
